@@ -524,7 +524,7 @@ KGpgItemModel::refreshGroups()
 bool
 KGpgItemModel::isDefaultKey(const KGpgNode *node) const
 {
-	return !m_default.isEmpty() && (m_default == node->getId().right(m_default.length()));
+	return !m_default.isEmpty() && (node->getId().rightRef(m_default.length()).compare(m_default) == 0);
 }
 
 void
